@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2011. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************


REM ******************
REM * Initialization *
REM ******************

rem flush errorlevel env. var in case it was unfortunately set in
rem the Windows session before running the script...
set ERRORLEVEL=

setlocal

rem repotools 2.x leaks this environment variable which prevents repotools 3.x from provisioning the server
set JAZZ_PROVISION_PROFILES=

rem Ensure the app_upgrade script was not called directly.
set INVALID_LAUNCH=false
if DEFINED SCRIPT_DIR goto :LBLLOCALMSG
set INVALID_LAUNCH=true
for /f "delims=" %%i in ('cd') do set START_DIR=%%i
set SCRIPT_DIR=%~dp0
set SCRIPT_DIR="%SCRIPT_DIR:~0,-1%"

:LBLLOCALMSG
rem Set locale messages
call %SCRIPT_DIR%\locale.bat
set MSG_FILE_NAME=MESSAGES%LANG_SUFFIX%.bat
set MSG_FILE_PATH=%SCRIPT_DIR%\messages\%MSG_FILE_NAME%

rem Exit in case of invalid launch
if %INVALID_LAUNCH% == true (
	%MSG_FILE_PATH% INVALID_LAUNCH
)


REM *********************
REM * Arguments reading *
REM *********************

rem First argument is the kind of upgrading
rem Should be only -jts, -rtc, -rqm or -rrc
if %1. == . (
	%MSG_FILE_PATH% MISSING_APP_TYPE
)
set FIRST_PARAM=%1
if %1 == -jts goto :LBLSETPARAMS
if %1 == -ccm goto :LBLSETPARAMS
if %1 == -qm goto :LBLSETPARAMS
if %1 == -rm goto :LBLSETPARAMS
%MSG_FILE_PATH% INVALID_APP_TYPE %1
exit /b 10

:LBLSETPARAMS
shift
set UPGRADED_APP=%FIRST_PARAM:~1%
rem Set parameters values from file
call %SCRIPT_DIR%\params\%UPGRADED_APP%_params%LANG_SUFFIX%.bat

rem Starting dir should be server dir
cd %SCRIPT_DIR%\..
for /f "delims=" %%i in ('cd') do set SERVER_DIR=%%i
if NOT "%START_DIR%" == "%SERVER_DIR%" (
	if "%1" == "-help" goto LBLHELP
	%MSG_FILE_PATH% INVALID_START_DIR %UPGRADED_APP%_upgrade.bat "%SERVER_DIR%"
)


:LBLARGS
if %1_ == _ goto :LBLVERIFPARAM & REM Jump when all parameters are consumed
if NOT %UPGRADED_APP% == jts (
	if /I "%1" == "-oldApplicationHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		if NOT EXIST %2 %MSG_FILE_PATH% INVALID_PARAM_DIR %1 %2&exit /b 2
		set OLD_APPLICATION_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-applicationContextRoot" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set APPLICATION_CONTEXT_ROOT=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-newApplicationHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		if NOT EXIST %2 %MSG_FILE_PATH% INVALID_PARAM_DIR %1 %2&exit /b 2
		set NEW_APPLICATION_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-createJTSTables" (
		set CREATE_JTS_TABLES=createTables
		shift
		goto LBLARGS
	)
	if /I "%1" == "-ignoreJTSVersionCheck" (
		set IGNORE_JTS_VERSION_CHECK=ignoreJTSVersionCheck
		shift
		goto LBLARGS
	)	
)
if NOT %UPGRADED_APP% == ccm if NOT %UPGRADED_APP% == qm (
	if /I "%1" == "-oldJTSHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		if NOT EXIST %2 %MSG_FILE_PATH% INVALID_PARAM_DIR %1 %2&exit /b 2
		set OLD_JTS_HOME=%2
		shift
		shift
		goto LBLARGS
	)
)
if /I "%1" == "-updateTomcatFiles" (
	if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
	if NOT %2_ == yes_ if NOT %2_ == no_ %MSG_FILE_PATH% INVALID_PARAM_VALUE %1 %2&exit /b 2
	set UPDATE_TOMCAT_FILES=%2
	shift
	shift
	goto LBLARGS
)
if %UPGRADED_APP% == rm (
	if /I "%1" == "-oldJTSContextRoot" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_JTS_CONTEXT_ROOT=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-oldApplicationTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-oldJTSTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_JTS_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-newJTSContextRoot" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set JTS_CONTEXT_ROOT=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-jtsURL" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set JTS_PUBLIC_URL=%2
		shift
		shift
		goto LBLARGS
	)
) else (
	if /I "%1" == "-oldTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-jtsContextRoot" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set JTS_CONTEXT_ROOT=%2
		shift
		shift
		goto LBLARGS
	)
)
if %UPGRADED_APP% == jts (
	if /I "%1" == "-oldJTSVersion" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_JTS_VERSION=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-newTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1
		set NEW_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
) else (
	if /I "%1" == "-newApplicationTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set NEW_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
	if /I "%1" == "-newJTSTomcatHome" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set NEW_JTS_TOMCAT_HOME=%2
		shift
		shift
		goto LBLARGS
	)
)
if %UPGRADED_APP% == ccm (
	if /I "%1" == "-oldApplicationVersion" (
		if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
		set OLD_APPLICATION_VERSION=%2
		shift
		shift
		goto LBLARGS
	)
)
if /I "%1" == "-newJTSHome" (
	if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
	if NOT EXIST %2 %MSG_FILE_PATH% INVALID_PARAM_DIR %1 %2&exit /b 2
	set NEW_JTS_HOME=%2
	shift
	shift
	goto LBLARGS
)
if /I "%1" == "-noPrompt" (
	set NO_PROMPT=noPrompt
	shift
	goto LBLARGS
)
if /I "%1" == "-noVerify" (
	set NO_VERIFY=false
	shift
	goto LBLARGS
)
if /I "%1" == "-overwrite" (
	set OVERWRITE=overwrite=yes
	shift
	goto LBLARGS
)
if /I "%1" == "-importFromFile" (
	if %2. == . %MSG_FILE_PATH% MISSING_PARAM_VALUE %1&exit /b 2
	if NOT EXIST %2 %MSG_FILE_PATH% INVALID_PARAM_FILE %1 %2&exit /b 2
	set IMPORT_FROM_FILE=%2
	shift
	shift
	goto LBLARGS
)
if /I "%1" == "-noStepPrompt" (
	set NO_STEP_PROMPT=true
	shift
	goto LBLARGS
)
if /I "%1" == "-help" (
	goto LBLHELP
)
REM Display msg, help and exit 2
%MSG_FILE_PATH% INVALID_PARAM %1


REM ************************
REM * Parameters verifying *
REM ************************
rem
rem RTC parameters rules
rem ====================
rem 1) 2.x to 3.x upgrade
rem ---------------------
rem  -oldApplicationHome: mandatory, no default
rem  -applicationRoot:    optional, default=jazz
rem  -oldJTSHome:         --- (forbidden)
rem  -jtsContextRoot:     optional, default=jts
rem  -updateType:         optional, default=JAZZ_AND_TOMCAT
rem  -oldTomcatHome:      optional, default=tomcat
rem  -newApplicationHome: mandatory, no default
rem  -newJtsHome:         optional, default=newAppHome
rem  -newTomcatHome:      optional, default=tomcat
rem
rem 2) 3.0 to 3.x upgrade
rem ---------------------
rem  -oldApplicationHome: mandatory, no default
rem  -applicationRoot:    optional, default=jazz
rem  -oldJTSHome:         mandatory, no default
rem  -jtsContextRoot:     optional, default=jts
rem  -updateType:         optional, default=JAZZ_AND_TOMCAT
rem  -oldTomcatHome:      optional, default=tomcat
rem  -newApplicationHome: mandatory, no default
rem  -newJtsHome:         optional, default=newAppHome
rem  -newTomcatHome:      optional, default=tomcat

:LBLVERIFPARAM

REM Infer the previous version based on the existence of the scr.xml file
REM Also set application context root if not set
if %UPGRADED_APP% == jts (
	set PREVIOUS_VERSION=3.0
	goto :LBLENDVERIF0b
)
set PREVIOUS_VERSION=2.x
if NOT "%APPLICATION_CONTEXT_ROOT%" == "" goto :LBLENDVERIF0a
if EXIST %OLD_APPLICATION_HOME%\%UPGRADED_APP%\scr.xml (
	set PREVIOUS_VERSION=3.0
	set APPLICATION_CONTEXT_ROOT=%UPGRADED_APP%
	goto :LBLENDVERIF0b
)
if %UPGRADED_APP% == rm (
	set APPLICATION_CONTEXT_ROOT=rdm
) else (
	set APPLICATION_CONTEXT_ROOT=jazz
)
:LBLENDVERIF0a
if EXIST %OLD_APPLICATION_HOME%\%APPLICATION_CONTEXT_ROOT%\scr.xml (
	set PREVIOUS_VERSION=3.0
)
:LBLENDVERIF0b

REM Infer old JTS context root if not set
if NOT %UPGRADED_APP% == rm goto :LBLENDVERIF0d
if "%OLD_JTS_CONTEXT_ROOT%" == "" goto :LBLENDVERIF0c
if NOT %PREVIOUS_VERSION% == 2.x (
	if NOT %JTS_CONTEXT_ROOT% == %OLD_JTS_CONTEXT_ROOT% (
		%MSG_FILE_PATH% INVALID_PARAM_VALUE -oldJTSContextRoot %OLD_JTS_CONTEXT_ROOT%
		%MSG_FILE_PATH% INVALID_PARAM_VALUE -newJTSContextRoot %JTS_CONTEXT_ROOT%
		exit /b 3
	)
)
:LBLENDVERIF0c
if %PREVIOUS_VERSION% == 2.x (
	set OLD_JTS_CONTEXT_ROOT=jazz
) else (
	set OLD_JTS_CONTEXT_ROOT=%JTS_CONTEXT_ROOT%
)
:LBLENDVERIF0d

REM Infer and verify old application parameters
rem -------------------------------------------

rem Verify OLD_APPLICATION_HOME, APPLICATION_CONTEXT_ROOT and NEW_APPLICATION_HOME
rem ------------------------------------------------------------------------------
if %UPGRADED_APP% == jts goto :LBLENDVERIF1

rem Home directory: OLD_APPLICATION_HOME
if NOT DEFINED OLD_APPLICATION_HOME (
	%MSG_FILE_PATH% MISSING_HOME_PARAM -oldApplicationHome
	exit /b 3
)
set TMP_DIR=%OLD_APPLICATION_HOME:"=%
set OLD_APPLICATION_HOME="%TMP_DIR%"
if NOT EXIST %OLD_APPLICATION_HOME% (
	%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_APPLICATION_HOME%
	exit /b 3
)
if NOT "%TMP_DIR:~1,2%" == ":\" (
	%MSG_FILE_PATH% RELATIVE_PARAM_DIR -oldApplicationHome %OLD_APPLICATION_HOME%
	exit /b 3
)
cd /d %OLD_APPLICATION_HOME%\..

REM Context root: APPLICATION_CONTEXT_ROOT
if NOT DEFINED APPLICATION_CONTEXT_ROOT (
	set APPLICATION_CONTEXT_ROOT=jazz
)

rem Old version: OLD_APPLICATION_VERSION
if %UPGRADED_APP% == ccm (
	if DEFINED OLD_APPLICATION_VERSION (
		set OLD_APPLICATION_VERSION_ARG=oldApplicationVersion=%OLD_APPLICATION_VERSION%
	)
)

rem Repotools command: OLD_APPLICATION_CMD
rem RM 3.0.x does not have its own repotools or teamserver.properties, so continue to the next step
if %PREVIOUS_VERSION% == 2.x (
	set CMD_NAME=repotools.bat
) else (
	if %UPGRADED_APP% == rm (
		goto :LBLENDVERIFYOLDAPP
	)
	set CMD_NAME=repotools-%APPLICATION_CONTEXT_ROOT%.bat
)
for /f "delims=" %%i in ('cd') do set OLD_APP_PARENT_DIR="%%i"
if NOT EXIST %OLD_APP_PARENT_DIR%\%CMD_NAME% (
	if %PREVIOUS_VERSION% == 2.x (
		%MSG_FILE_PATH% CMD_NOT_FOUND_2X_APP %OLD_APP_PARENT_DIR%\%CMD_NAME% %OLD_APPLICATION_HOME%
	) else (
		%MSG_FILE_PATH% CMD_NOT_FOUND_OLD_APP %OLD_APP_PARENT_DIR%\%CMD_NAME% %OLD_APPLICATION_HOME% %APPLICATION_CONTEXT_ROOT%
	)
	exit /b 3
)

rem Old application teamserver.properties file
if %UPGRADED_APP% == rm (
	set TMP_CTXT_ROOT=jazz
) else (
	set TMP_CTXT_ROOT=%APPLICATION_CONTEXT_ROOT%
)
set OLD_APP_TSP_FILE=%OLD_APPLICATION_HOME:"=%\%TMP_CTXT_ROOT%\teamserver.properties
set OLD_APP_TSP_FILE="%OLD_APP_TSP_FILE%"
if NOT EXIST %OLD_APP_TSP_FILE% (
	if %PREVIOUS_VERSION% == 2.x (
		%MSG_FILE_PATH% TSP_NOT_FOUND_2X_APP %OLD_APP_TSP_FILE% %OLD_APPLICATION_HOME%
	) else (
		%MSG_FILE_PATH% TSP_NOT_FOUND_OLD_APP %OLD_APP_TSP_FILE% %OLD_APPLICATION_HOME% %APPLICATION_CONTEXT_ROOT%
	)
	exit /b 3
)
:LBLENDVERIFYOLDAPP

rem Home directory: NEW_APPLICATION_HOME
if NOT DEFINED NEW_APPLICATION_HOME (
	%MSG_FILE_PATH% MISSING_HOME_PARAM -newApplicationHome
	exit /b 3
)
set TMP_DIR=%NEW_APPLICATION_HOME:"=%
if NOT "%TMP_DIR%" == "." (
	if "%TMP_DIR:~1,2%" == ":\" (
		set NEW_APPLICATION_HOME="%TMP_DIR%"
	) else (
		set NEW_APPLICATION_HOME="%START_DIR%\%TMP_DIR%"
	)
) else (
	set NEW_APPLICATION_HOME="%START_DIR%"
)
if NOT EXIST %NEW_APPLICATION_HOME% (
	%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_APPLICATION_HOME%
	exit /b 3
)
cd /d %NEW_APPLICATION_HOME%\..

rem Repotools command: NEW_APP_CMD
for /f "delims=" %%i in ('cd') do set NEW_APP_PARENT_DIR="%%i"
if %UPGRADED_APP% == rm goto LBLENDVERIF1
set NEW_APPLICATION_CMD=repotools-%APPLICATION_CONTEXT_ROOT%.bat
if NOT EXIST %NEW_APP_PARENT_DIR%\%NEW_APPLICATION_CMD% (
	%MSG_FILE_PATH% CMD_NOT_FOUND_NEW_APP %NEW_APP_PARENT_DIR%\%NEW_APPLICATION_CMD% %NEW_APPLICATION_HOME% %APPLICATION_CONTEXT_ROOT% %PREVIOUS_VERSION%
	exit /b 3
)

rem New application teamserver.properties file
set NEW_APP_TSP_FILE=%NEW_APPLICATION_HOME:"=%\%APPLICATION_CONTEXT_ROOT%\teamserver.properties
set NEW_APP_TSP_FILE="%NEW_APP_TSP_FILE%"
if NOT EXIST %NEW_APP_TSP_FILE% (
	%MSG_FILE_PATH% TSP_NOT_FOUND_NEW_APP %NEW_APP_TSP_FILE% %NEW_APPLICATION_HOME% %APPLICATION_CONTEXT_ROOT% %PREVIOUS_VERSION%
	exit /b 3
)
:LBLENDVERIF1

REM Infer and verify JTS parameters
rem -------------------------------

rem Context root: JTS_CONTEXT_ROOT (always defined)
if NOT DEFINED JTS_CONTEXT_ROOT (
	set JTS_CONTEXT_ROOT=jts
)

rem Old version: OLD_JTS_VERSION
if %UPGRADED_APP% == jts (
	if DEFINED OLD_JTS_VERSION (
		set OLD_JTS_VERSION_ARG=oldJTSVersion=%OLD_JTS_VERSION%
	)
)

rem Old Home directory: OLD_JTS_HOME
if NOT %UPGRADED_APP% == rm if NOT %UPGRADED_APP% == jts (
    goto :LBLVERIFPARAMNEWJTS
)
if %UPGRADED_APP% == rm (
	if NOT DEFINED OLD_JTS_HOME (
		set OLD_JTS_HOME=%OLD_APPLICATION_HOME%
	)
	if DEFINED JTS_PUBLIC_URL (
		set JTS_PUBLIC_URL_ARG=jtsURL=%JTS_PUBLIC_URL%
	)
)
if NOT DEFINED OLD_JTS_HOME (
	%MSG_FILE_PATH% MISSING_HOME_PARAM -oldJTSHome
	exit /b 3
)
set TMP_DIR=%OLD_JTS_HOME:"=%
set OLD_JTS_HOME="%TMP_DIR%"
if NOT EXIST %OLD_JTS_HOME% (
	%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_JTS_HOME%
	exit /b 3
)
if NOT "%TMP_DIR:~1,2%" == ":\" (
	%MSG_FILE_PATH% RELATIVE_PARAM_DIR -oldJTSHome %OLD_JTS_HOME%
	exit /b 3
)
if %UPGRADED_APP% == rm (
    goto :LBLVERIFPARAMNEWJTS
)

cd /d %OLD_JTS_HOME%\..

rem Check old repotools command
for /f "delims=" %%i in ('cd') do set OLD_JTS_PARENT_DIR="%%i"
if NOT EXIST %OLD_JTS_PARENT_DIR%\repotools-%JTS_CONTEXT_ROOT%.bat (
	%MSG_FILE_PATH% CMD_NOT_FOUND_OLD_JTS %OLD_JTS_PARENT_DIR%\repotools-%JTS_CONTEXT_ROOT%.bat %OLD_JTS_HOME% %JTS_CONTEXT_ROOT%
	exit /b 3
)

rem Old JTS teamserver.properties file
set OLD_JTS_TSP_FILE=%OLD_JTS_HOME:"=%\%JTS_CONTEXT_ROOT%\teamserver.properties
set OLD_JTS_TSP_FILE="%OLD_JTS_TSP_FILE%"
if NOT EXIST %OLD_JTS_TSP_FILE% (
	%MSG_FILE_PATH% TSP_NOT_FOUND_OLD_JTS %OLD_JTS_TSP_FILE% %OLD_JTS_HOME% %JTS_CONTEXT_ROOT%
	exit /b 3
)

:LBLVERIFPARAMNEWJTS

rem New Home directory: NEW_JTS_HOME (always defined)
if NOT DEFINED NEW_JTS_HOME (
	if %UPGRADED_APP% == jts (
		set NEW_JTS_HOME="%START_DIR%\conf"
	) else if %UPGRADED_APP% == rm (
		set NEW_JTS_HOME="%START_DIR%\conf"
	) else (
		set NEW_JTS_HOME=%NEW_APPLICATION_HOME%
	)
)
set TMP_DIR=%NEW_JTS_HOME:"=%
if NOT "%TMP_DIR%" == "." (
	if "%TMP_DIR:~1,2%" == ":\" (
		set NEW_JTS_HOME="%TMP_DIR%"
	) else (
		set NEW_JTS_HOME="%START_DIR%\%TMP_DIR%"
	)
) else (
	set NEW_JTS_HOME="%START_DIR%"
)
if NOT EXIST %NEW_JTS_HOME% (
	%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_JTS_HOME%
	exit /b 3
)
cd /d %NEW_JTS_HOME%\..

rem Repotools command: NEW_JTS_CMD (not defined for 3.0 upgrade)
for /f "delims=" %%i in ('cd') do set NEW_JTS_PARENT_DIR="%%i"
set NEW_JTS_CMD=repotools-%JTS_CONTEXT_ROOT%.bat
if NOT EXIST %NEW_JTS_PARENT_DIR%\%NEW_JTS_CMD% (
	%MSG_FILE_PATH% CMD_NOT_FOUND_NEW_JTS %NEW_JTS_PARENT_DIR%\%NEW_JTS_CMD% %NEW_JTS_HOME% %JTS_CONTEXT_ROOT%
	exit /b 3
)
if %UPGRADED_APP% == jts (
	rem For JTS upgrade the new application command is the new JTS repotools
	set NEW_APPLICATION_CMD=%NEW_JTS_CMD%
	set NEW_APP_PARENT_DIR=%NEW_JTS_PARENT_DIR%
) else if %UPGRADED_APP% == rm (
    rem rm upgrade scripts are run from the 3.0.1 JTS repotools
    set NEW_APPLICATION_CMD=%NEW_JTS_CMD%
)

rem New JTS teamserver.properties file
set NEW_JTS_TSP_FILE=%NEW_JTS_HOME:"=%\%JTS_CONTEXT_ROOT%\teamserver.properties
set NEW_JTS_TSP_FILE="%NEW_JTS_TSP_FILE%"
if NOT EXIST %NEW_JTS_TSP_FILE% (
	%MSG_FILE_PATH% TSP_NOT_FOUND_NEW_JTS %NEW_JTS_TSP_FILE% %NEW_JTS_HOME% %JTS_CONTEXT_ROOT%
	exit /b 3
)

REM Infer and verify Tomcat parameters
rem ----------------------------------

if DEFINED UPDATE_TOMCAT_FILES (
	set UPDATE_TOMCAT_FILES_ARG=updateTomcatFiles=%UPDATE_TOMCAT_FILES%
)

rem Old Tomcat home
if NOT DEFINED OLD_TOMCAT_HOME goto :LBLENDVERIF2
set TMP_DIR=%OLD_TOMCAT_HOME:"=%
set OLD_TOMCAT_HOME="%TMP_DIR%"
if NOT "%TMP_DIR:~1,2%" == ":\" (
	if %UPGRADED_APP% == rm (
		%MSG_FILE_PATH% RELATIVE_PARAM_DIR -oldApplicationTomcatHome %OLD_TOMCAT_HOME%
	) else (
		%MSG_FILE_PATH% RELATIVE_PARAM_DIR -oldTomcatHome %OLD_TOMCAT_HOME%
	)
	exit /b 3
)
if NOT EXIST %OLD_TOMCAT_HOME% (
	if NOT EXIST %OLD_APP_PARENT_DIR%\%OLD_TOMCAT_HOME% (
		if %OLD_TOMCAT_HOME::=% == %OLD_TOMCAT_HOME% (
			%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_APP_PARENT_DIR%%OLD_TOMCAT_HOME%
		) else (
			%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_TOMCAT_HOME%
		)
		exit /b 3
	)
)
if %UPGRADED_APP% == rm (
	set OLD_TOMCAT_HOME_ARG=oldApplicationTomcatHome=%OLD_TOMCAT_HOME%
) else (
	set OLD_TOMCAT_HOME_ARG=oldTomcatHome=%OLD_TOMCAT_HOME%
)
:LBLENDVERIF2

if NOT %UPGRADED_APP% == rm goto :LBLENDVERIF3
if NOT DEFINED OLD_JTS_TOMCAT_HOME goto :LBLENDVERIF3
set TMP_DIR=%OLD_JTS_TOMCAT_HOME:"=%
set OLD_JTS_TOMCAT_HOME="%TMP_DIR%"
if NOT "%TMP_DIR:~1,2%" == ":\" (
	%MSG_FILE_PATH% RELATIVE_PARAM_DIR -oldJTSTomcatHome %OLD_JTS_TOMCAT_HOME%
	exit /b 3
)
if NOT EXIST %OLD_JTS_TOMCAT_HOME% (
	if NOT EXIST %OLD_APP_PARENT_DIR%\%OLD_JTS_TOMCAT_HOME% (
		if %OLD_JTS_TOMCAT_HOME::=% == %OLD_JTS_TOMCAT_HOME% (
			%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_APP_PARENT_DIR%%OLD_JTS_TOMCAT_HOME%
		) else (
			%MSG_FILE_PATH% DIR_NOT_FOUND %OLD_JTS_TOMCAT_HOME%
		)
		exit /b 3
	)
)
set OLD_JTS_TOMCAT_HOME_ARG=oldJTSTomcatHome=%OLD_JTS_TOMCAT_HOME%
:LBLENDVERIF3

rem New Tomcat home
if NOT DEFINED NEW_TOMCAT_HOME goto :LBLENDVERIF4
set TMP_DIR=%NEW_TOMCAT_HOME:"=%
if NOT "%TMP_DIR%" == "." (
	if "%TMP_DIR:~1,2%" == ":\" (
		set NEW_TOMCAT_HOME="%TMP_DIR%"
	) else (
		set NEW_TOMCAT_HOME="%START_DIR%\%TMP_DIR%"
	)
) else (
	set NEW_TOMCAT_HOME="%START_DIR%"
)
if NOT EXIST %NEW_TOMCAT_HOME% (
	if NOT EXIST %NEW_APP_PARENT_DIR%\%NEW_TOMCAT_HOME% (
		if %NEW_TOMCAT_HOME::=% == %NEW_TOMCAT_HOME% (
			%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_APP_PARENT_DIR%\%NEW_TOMCAT_HOME%
		) else (
			%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_TOMCAT_HOME%
		)
		exit /b 3
	)
)
if %UPGRADED_APP% == jts (
	set NEW_TOMCAT_HOME_ARG=newTomcatHome=%NEW_TOMCAT_HOME%
) else (
	set NEW_TOMCAT_HOME_ARG=newApplicationTomcatHome=%NEW_TOMCAT_HOME%
)
:LBLENDVERIF4

if %UPGRADED_APP% == jts goto :LBLENDVERIF5
if NOT DEFINED NEW_JTS_TOMCAT_HOME goto :LBLENDVERIF5
set TMP_DIR=%NEW_JTS_TOMCAT_HOME:"=%
if NOT "%TMP_DIR%" == "." (
	if "%TMP_DIR:~1,2%" == ":\" (
		set NEW_JTS_TOMCAT_HOME="%TMP_DIR%"
	) else (
		set NEW_JTS_TOMCAT_HOME="%START_DIR%\%TMP_DIR%"
	)
) else (
	set NEW_JTS_TOMCAT_HOME="%START_DIR%"
)
if NOT EXIST %NEW_JTS_TOMCAT_HOME% (
	if NOT EXIST %NEW_APP_PARENT_DIR%\%NEW_JTS_TOMCAT_HOME% (
		if %NEW_JTS_TOMCAT_HOME::=% == %NEW_JTS_TOMCAT_HOME% (
			%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_APP_PARENT_DIR%\%NEW_JTS_TOMCAT_HOME%
		) else (
			%MSG_FILE_PATH% DIR_NOT_FOUND %NEW_JTS_TOMCAT_HOME%
		)
		exit /b 3
	)
)
set NEW_JTS_TOMCAT_HOME_ARG=newJTSTomcatHome=%NEW_JTS_TOMCAT_HOME%
:LBLENDVERIF5


REM Verify Import parameters
rem ------------------------

REM Import from file: IMPORT_FROM_FILE
if NOT DEFINED IMPORT_FROM_FILE (
	if %PREVIOUS_VERSION% == 2.x (
		if NOT %UPGRADED_APP% == ccm if NOT %UPGRADED_APP% == jts (
			%MSG_FILE_PATH% MISSING_IMPORT_FROM_FILE %UPGRADED_APP%
			exit /b 3
		)
	)
	goto :LBLENDVERIF6
)
set TMP_FILE=%IMPORT_FROM_FILE:"=%
if NOT "%TMP_FILE:~1,2%" == ":\" (
	set IMPORT_FROM_FILE="%START_DIR%\%TMP_FILE%"
)
:LBLENDVERIF6

REM ************************************************************
REM * For 3.0.x upgrades, if the data warehouse is configured
REM * -createDataWarehouse must be called to upgrade the schema.
REM * Only upgrade the warehouse for JTS upgrades since customers
REM * must upgrade to the 3.0.1.2 JTS before upgrading applications.
REM
REM Check if the com.ibm.team.datawarehouse.db.jdbc.location property
REM is set in the new TSP. The new updateConfigFile will carry over
REM the data warehouse settings from the 3.0.1 version. Hence, if the user
REM skipped configuring the warehouse in 3.0.1, this property should not exist
REM in the TSP. There may be corner cases here which we can document.
REM
REM ************************************************************
set UPGRADE_DATA_WAREHOUSE=false
if %PREVIOUS_VERSION% == 2.x goto LBLENDVERIF7
if NOT %UPGRADED_APP% == jts goto LBLENDVERIF7
set FIND_CMD=%SystemRoot%\system32\find.exe

rem Check if property is set in the new TSP
set /A N1=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "com.ibm.team.datawarehouse.db.jdbc.location" %OLD_JTS_TSP_FILE%') do set /A N1=%%k
if %N1% EQU 0 goto :LBLENDVERIF7

rem Check if at least one line with property is not commented
set /A N2=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "#com.ibm.team.datawarehouse.db.jdbc.location" %OLD_JTS_TSP_FILE%') do set /A N2=%%k
if %N1% GTR %N2% set UPGRADE_DATA_WAREHOUSE=true
:LBLENDVERIF7

REM **************
REM * Start exec *
REM **************

:LBLSTARTEXEC
call %MSG_FILE_PATH% BANNER_%UPGRADED_APP% %PREVIOUS_VERSION%

REM *********************
REM * First step switch *
REM *********************

cd %START_DIR%
set STEP_ERROR=0
set /A INITIAL_STEP=0
set REBUILD_TXT_INDICES=false

rem Compute max steps to execute
if %UPGRADED_APP% == jts (
	if %UPGRADE_DATA_WAREHOUSE% == true (
		set /A MAX_STEPS=2
	) else (
		set /A MAX_STEPS=1
	)
) else if %UPGRADED_APP% == ccm (
	if %PREVIOUS_VERSION% == 3.0 (
		set /A MAX_STEPS=1
	) else (
		if DEFINED IMPORT_FROM_FILE (
			set /A MAX_STEPS=4
		) else (
			set /A MAX_STEPS=6
		)
	)
) else if %UPGRADED_APP% == qm (
	if %PREVIOUS_VERSION% == 3.0 (
		set /A MAX_STEPS=1
	) else (
		set /A MAX_STEPS=4
	)
) else if %UPGRADED_APP% == rm (
	if %PREVIOUS_VERSION% == 3.0 (
		set /A MAX_STEPS=0
	) else (
		set /A MAX_STEPS=1
	)
)
set /A LAST_STEP=-1
set /A LAST_RETURN=0
set VERIF_CMD=%SCRIPT_DIR%\app_verify.bat
set CHECK_TXT_INDICES_CMD=%SCRIPT_DIR%\check_text_indices.bat
set LOG_FILE=%SCRIPT_DIR%\.%UPGRADED_APP%_upgrade.log
if EXIST %LOG_FILE% (
	for /f "tokens=1,2,3" %%i in ('type %LOG_FILE%') do (
		set /A LAST_STEP=%%i
		set /A LAST_RETURN=%%j
		if NOT "%%k" == "" set LAST_STEP_INFO=%%k
	)
	goto :LBLCHECKLASTSTEPINFO
)
set /A CURRENT_STEP=%INITIAL_STEP%
goto :LBLENDVERIF

:LBLCHECKLASTSTEPINFO
rem Check last step info
if "%LAST_STEP_INFO%" == "REBUILD_TXT_INDICES" (
	set REBUILD_TXT_INDICES=true
	set /A MAX_STEPS = 2
)
rem debug: echo REBUILD_TXT_INDICES=%REBUILD_TXT_INDICES%
rem debug: echo MAX_STEPS=%MAX_STEPS%

:LBLFIRSTSTEP
REM Script was already executed
if %LAST_RETURN% EQU 0 (
	REM Previous execution finished without any error
	set /A CURRENT_STEP = LAST_STEP + 1
	if %LAST_STEP% GEQ %MAX_STEPS% goto :LBLFIRSTSTEP0
	goto :LBLFIRSTSTEP1
)

REM Previous run finished with an error, restart from failing step
set /A CURRENT_STEP = LAST_STEP
if %LAST_STEP% EQU %INITIAL_STEP% (
	call %MSG_FILE_PATH% INITIAL_STEP_FAILED
	goto LBLSTEP%CURRENT_STEP%
)
call %MSG_FILE_PATH% LAST_STEP_FAILED %LAST_STEP%
set /A STEP_NUM_MAX=%LAST_STEP%
goto :LBLFIRSTSTEPSUB

:LBLFIRSTSTEP0
call %MSG_FILE_PATH% ALREADY_RUN
set /A STEP_NUM_MAX=%MAX_STEPS%
goto :LBLFIRSTSTEPSUB

:LBLFIRSTSTEP1
call %MSG_FILE_PATH% LAST_STEP_PASSED %LAST_STEP% %CURRENT_STEP%
set /A STEP_NUM_MAX=%CURRENT_STEP%
goto :LBLFIRSTSTEPSUB

:LBLFIRSTSTEPSUB
set ANSWER=
call %MSG_FILE_PATH% ENTER_NEXT_STEP %INITIAL_STEP% %STEP_NUM_MAX%
set /P ANSWER=
if "%ANSWER%" == "" goto LBLEND
set /A STEP_NUMBER=%ANSWER%
if NOT %ANSWER% == 0 if %STEP_NUMBER% EQU 0 (
	call %MSG_FILE_PATH% INTEGER_STEP_NUMBER %ANSWER%
	goto :LBLFIRSTSTEPSUB
)
if %STEP_NUMBER% LSS %INITIAL_STEP% (
	call %MSG_FILE_PATH% INVALID_STEP_NUMBER %ANSWER%
	goto :LBLFIRSTSTEPSUB
)
if %STEP_NUMBER% GTR %MAX_STEPS% (
	call %MSG_FILE_PATH% MAX_STEP_NUMBER %MAX_STEPS% %STEP_NUMBER%
	goto :LBLFIRSTSTEPSUB
)
if %STEP_NUMBER% GTR %STEP_NUM_MAX% (
	call %MSG_FILE_PATH% NUM_MAX_STEP_NUMBER %STEP_NUM_MAX% %STEP_NUMBER%
	goto :LBLFIRSTSTEPSUB
)
set /A CURRENT_STEP=%STEP_NUMBER%
if %CURRENT_STEP% EQU %INITIAL_STEP% goto LBLENDVERIF


REM **********************
REM * Verify Public URIs *
REM **********************

if "%NO_VERIFY%" == "false" goto LBLENDVERIF
if NOT EXIST %VERIF_CMD% goto LBLENDVERIF
call %VERIF_CMD%
if NOT %ERRORLEVEL% == 0 goto LBLEND

:LBLENDVERIF
goto LBLSTEP%CURRENT_STEP%

REM **************
REM * Steps loop *
REM **************

:LBLSTEP0
set CURRENT_STEP_MSG=STEP_0
if %UPGRADED_APP% == jts (
    set STEP_DIR=%NEW_JTS_PARENT_DIR%
) else if %UPGRADED_APP% == rm (
    set STEP_DIR=%NEW_JTS_PARENT_DIR%
) else (
    set STEP_DIR=%NEW_APP_PARENT_DIR%
)
if %UPGRADED_APP% == jts (
	set CMD_ARGUMENTS=oldJTSHome=%OLD_JTS_HOME% jtsContextRoot=%JTS_CONTEXT_ROOT% %UPDATE_TOMCAT_FILES_ARG% %OLD_TOMCAT_HOME_ARG% newJTSHome=%NEW_JTS_HOME% %NEW_TOMCAT_HOME_ARG% %OLD_JTS_VERSION_ARG%
) else if %UPGRADED_APP% == rm (
	set CMD_ARGUMENTS=oldApplicationHome=%OLD_APPLICATION_HOME% applicationContextRoot=%APPLICATION_CONTEXT_ROOT% oldJTSHome=%OLD_JTS_HOME% oldJTSContextRoot=%OLD_JTS_CONTEXT_ROOT% %UPDATE_TOMCAT_FILES_ARG% %OLD_TOMCAT_HOME_ARG% %OLD_JTS_TOMCAT_HOME_ARG% newApplicationHome=%NEW_APPLICATION_HOME% newJTSHome=%NEW_JTS_HOME% newJTSContextRoot=%JTS_CONTEXT_ROOT% %NEW_TOMCAT_HOME_ARG% %NEW_JTS_TOMCAT_HOME_ARG% %JTS_PUBLIC_URL_ARG% %IGNORE_JTS_VERSION_CHECK%
) else (
	rem CCM and QM command arguments are identical
	set CMD_ARGUMENTS=oldApplicationHome=%OLD_APPLICATION_HOME% applicationContextRoot=%APPLICATION_CONTEXT_ROOT% %UPDATE_TOMCAT_FILES_ARG% %OLD_TOMCAT_HOME_ARG% newApplicationHome=%NEW_APPLICATION_HOME% newJTSHome=%NEW_JTS_HOME% jtsContextRoot=%JTS_CONTEXT_ROOT% %NEW_TOMCAT_HOME_ARG% %NEW_JTS_TOMCAT_HOME_ARG% %IGNORE_JTS_VERSION_CHECK% %OLD_APPLICATION_VERSION_ARG%
)
set STEP_CMD=%NEW_APPLICATION_CMD% -migration_%UPGRADED_APP%_updateConfigurationFiles %CMD_ARGUMENTS%
goto LBLRUNSTEP

:LBLSTEP1
if %UPGRADED_APP% == jts (
    set STEP_DIR=%NEW_JTS_PARENT_DIR%
) else if %UPGRADED_APP% == rm (
    set STEP_DIR=%NEW_JTS_PARENT_DIR%
) else (
    set STEP_DIR=%NEW_APP_PARENT_DIR%
)
if %UPGRADED_APP% == rm (
	set CURRENT_STEP_MSG=STEP_1_IMPORT %PREVIOUS_VERSION%
	set STEP_CMD=%NEW_APPLICATION_CMD% -migration_importApplicationData fromFile=%IMPORT_FROM_FILE% teamserver.properties=%NEW_JTS_HOME%\%JTS_CONTEXT_ROOT%\teamserver.properties %CREATE_JTS_TABLES% %NO_PROMPT%
) else if NOT DEFINED IMPORT_FROM_FILE (
	set CURRENT_STEP_MSG=STEP_1_ADD
	set STEP_CMD=%NEW_APPLICATION_CMD% -addTables %NO_PROMPT%
) else (
	set CURRENT_STEP_MSG=STEP_1_IMPORT %PREVIOUS_VERSION%
	set STEP_CMD=%NEW_APPLICATION_CMD% -import fromFile=%IMPORT_FROM_FILE% %NO_PROMPT%
)
goto LBLRUNSTEP

:LBLSTEP2
if %UPGRADED_APP% == jts (
	rem %UPGRADE_DATA_WAREHOUSE% is true in this case...
	set CURRENT_STEP_MSG=STEP_2_UPGRADE_DATA_WAREHOUSE
	set STEP_DIR=%NEW_JTS_PARENT_DIR%
	set STEP_CMD=%NEW_JTS_CMD% -createWarehouse teamserver.properties=%NEW_JTS_HOME%\%JTS_CONTEXT_ROOT%\teamserver.properties %NO_PROMPT%
) else if %REBUILD_TXT_INDICES% == true (
	set CURRENT_STEP_MSG=STEP_5
	set STEP_DIR=%NEW_APP_PARENT_DIR%
	set STEP_CMD=%NEW_APPLICATION_CMD% -rebuildTextIndices
) else (
	set CURRENT_STEP_MSG=STEP_2_EXPORT_USER_INFO
	set STEP_DIR=%NEW_APP_PARENT_DIR%
	set STEP_CMD=%NEW_APPLICATION_CMD% -migration_exportJTSData toFile=jtsData.tar %OVERWRITE%
)
goto LBLRUNSTEP

:LBLSTEP3
set CURRENT_STEP_MSG=STEP_3_IMPORT_USER_INFO
set STEP_DIR=%NEW_JTS_PARENT_DIR%
set STEP_CMD=%NEW_JTS_CMD% -migration_importJTSData fromFile=%NEW_APP_PARENT_DIR%\jtsData.tar createMappingFile=%NEW_APP_PARENT_DIR%\appli-mapping.txt %CREATE_JTS_TABLES% %OVERWRITE%
goto LBLRUNSTEP

:LBLSTEP4
set CURRENT_STEP_MSG=STEP_4
set STEP_DIR=%NEW_APP_PARENT_DIR%
set STEP_CMD=%NEW_APPLICATION_CMD% -migration_importUserMapping fromMappingFile=appli-mapping.txt
goto LBLRUNSTEP

REM =========================================
REM === Post-upgrade repotools commands ===
REM =========================================

:LBLSTEP5
set CURRENT_STEP_MSG=STEP_5
set STEP_DIR=%NEW_APP_PARENT_DIR%
set STEP_CMD=%NEW_APPLICATION_CMD% -rebuildTextIndices
goto LBLRUNSTEP

:LBLSTEP6
set CURRENT_STEP_MSG=STEP_6
set STEP_DIR=%NEW_APP_PARENT_DIR%
set STEP_CMD=%NEW_APPLICATION_CMD% -reindex
goto LBLRUNSTEP


REM *********************
REM * Step run function *
REM *********************

:LBLRUNSTEP
cd /d %STEP_DIR%
echo.
echo.
call %MSG_FILE_PATH% %CURRENT_STEP_MSG% %CURRENT_STEP%
call %MSG_FILE_PATH% STEP_DIR_CMD %STEP_DIR%
set TAB=    
echo %TAB%%STEP_CMD%
echo.
set RUN_STEP=
if NOT "%NO_STEP_PROMPT%" == "true" (
	call %MSG_FILE_PATH% ENTER_STEP_ACTION
	set /P RUN_STEP=
	echo.
) else (
	set RUN_STEP=E
)
if /I "%RUN_STEP%" == "E" goto :LBLRUNSTEP1
if /I "%RUN_STEP%" == "S" (
	if %CURRENT_STEP% EQU 0 goto :LBLRUNVERIF2
	goto :LBLRUNSTEP2
)
if /I "%RUN_STEP%" == "" goto :LBLEND
call %MSG_FILE_PATH% INVALID_STEP_ACTION %RUN_STEP%
goto LBLRUNSTEP

:LBLRUNSTEP1
call %STEP_CMD%
set STEP_ERROR=%ERRORLEVEL%
if NOT %STEP_ERROR% EQU 0 goto :LBLRUNSTEP2
if %CURRENT_STEP% NEQ 0 goto :LBLRUNSTEP2

REM Finish JTS teamserver.properties setup manually on step 0
:LBLRUNVERIF0
call %MSG_FILE_PATH% EDIT_TEAMSERVER_PROPERTIES JTS
call %MSG_FILE_PATH% PAUSE
set PAUSE=
set /P PAUSE=
if "%PAUSE%" == "" goto :LBLEND
if /I NOT "%PAUSE%" == "C" (
	call %MSG_FILE_PATH% INVALID_PAUSE_ACTION %PAUSE%
	goto :LBLRUNVERIF0
) 
notepad %NEW_JTS_TSP_FILE%"
if %UPGRADED_APP% == jts goto :LBLRUNVERIF2
if %UPGRADED_APP% == rm goto :LBLRUNVERIF2

:LBLRUNVERIF1
call %MSG_FILE_PATH% EDIT_TEAMSERVER_PROPERTIES %UPGRADED_APP%
call %MSG_FILE_PATH% PAUSE
set PAUSE=
set /P PAUSE=
if "%PAUSE%" == "" goto :LBLEND
if /I NOT "%PAUSE%" == "C" (
	call %MSG_FILE_PATH% INVALID_PAUSE_ACTION %PAUSE%
	goto :LBLRUNVERIF1
) 
notepad %NEW_APP_TSP_FILE%

:LBLRUNVERIF2
REM Verify URIs in teamserver.properties files
if "%NO_VERIFY%" == "false" goto :LBLRUNSTEP2
if NOT EXIST %VERIF_CMD% goto :LBLRUNSTEP2
call %VERIF_CMD%
if NOT %ERRORLEVEL% == 0 goto LBLEND_MIGRATION_FAILED

:LBLCHECKTXTINDICES
REM Copy the indices if necessary
if NOT %UPGRADED_APP% == ccm goto LBLRUNSTEP2
if NOT %PREVIOUS_VERSION% == 3.0 goto LBLRUNSTEP2
if NOT EXIST %CHECK_TXT_INDICES_CMD% goto LBLRUNSTEP2
call %CHECK_TXT_INDICES_CMD%
if %ERRORLEVEL% == 0 goto :LBLRUNSTEP2
rem Indices copy failed for any reason, hence we need to rebuild the text indices
set /A MAX_STEPS = 2
set REBUILD_TXT_INDICES=true
rem debug: echo REBUILD_TXT_INDICES=%REBUILD_TXT_INDICES%

:LBLRUNSTEP2
attrib -h %LOG_FILE% > nul
if %CURRENT_STEP% LSS %MAX_STEPS% (
	if %REBUILD_TXT_INDICES% == true (
		echo %CURRENT_STEP% %STEP_ERROR% REBUILD_TXT_INDICES > %LOG_FILE%
	) else (
		echo %CURRENT_STEP% %STEP_ERROR% > %LOG_FILE%
	)
) else (
	echo %CURRENT_STEP% %STEP_ERROR% > %LOG_FILE%
)
attrib +h %LOG_FILE%
if NOT %STEP_ERROR% EQU 0 goto LBLEND_MIGRATION_FAILED

:LBLRUNSTEP3
set /A CURRENT_STEP = CURRENT_STEP + 1
if %CURRENT_STEP% GTR %MAX_STEPS% (
	goto LBLEND_MIGRATION_SUCCESS
)
goto LBLSTEP%CURRENT_STEP%


REM *****************
REM * Help messages *
REM *****************

:LBLHELP
type %SCRIPT_DIR%\doc\%UPGRADED_APP%_help%LANG_SUFFIX%.txt
set STEP_ERROR=1
goto LBLEND

REM **********************
REM * Script end message *
REM **********************

:LBLEND_MIGRATION_FAILED
call %MSG_FILE_PATH% OVERALL_MIGRATION_FAILED %UPGRADED_APP% %CURRENT_STEP%
goto LBLEND

:LBLEND_MIGRATION_SUCCESS
if %UPGRADED_APP% == jts (
	call %MSG_FILE_PATH% OVERALL_MIGRATION_SUCCESS_JTS %UPGRADED_APP%
) else if %UPGRADED_APP% == rm (
	if %PREVIOUS_VERSION% == 2.x (
		call %MSG_FILE_PATH% OVERALL_MIGRATION_SUCCESS_RM %UPGRADED_APP%
	)
) else (
	call %MSG_FILE_PATH% OVERALL_MIGRATION_SUCCESS_CCM_QM %UPGRADED_APP%
)
goto LBLEND

REM **************
REM * Script end *
REM **************

:LBLEND
endlocal & exit /b %STEP_ERROR%
