@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2011. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************

setlocal
set /A RETURN_VALUE=0

set CHECK_TEXT_INDICES_LOG=%SCRIPT_DIR:"=%\check_text_indices.log
set CHECK_TEXT_INDICES_LOG="%CHECK_TEXT_INDICES_LOG%"

REM ********************************************
REM Check if the com.ibm.team.fulltext.indexLocation property exists
REM in the old and the new TSP and that is a relative path.
REM Otherwise, error out with the new message COPY_INDICES_FAILED
REM ********************************************

REM Old TSP
rem =======
set FIND_CMD=%SystemRoot%\system32\find.exe

rem Check property in the TSP file
set /A N1=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "com.ibm.team.fulltext.indexLocation" %OLD_APP_TSP_FILE%') do set /A N1=%%k
if %N1% EQU 0 (
	rem None was found => return
	call %MSG_FILE_PATH% COPY_INDICES_FAILED not-defined not-checked
	set /A RETURN_VALUE = 1
	goto :LBLEND
)

rem Check at least one line with property is not commented
set /A N2=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "#com.ibm.team.fulltext.indexLocation" %OLD_APP_TSP_FILE%') do set /A N2=%%k
if %N2% GEQ %N1% (
	rem All lines with property are commented => return
	call %MSG_FILE_PATH% COPY_INDICES_FAILED not-defined not-checked
	set /A RETURN_VALUE = 1
	goto :LBLEND
)

rem Get the text indices path
%FIND_CMD% "com.ibm.team.fulltext.indexLocation" %OLD_APP_TSP_FILE% | %FIND_CMD% /V "#com.ibm.team.fulltext.indexLocation" > %CHECK_TEXT_INDICES_LOG%
for /F "tokens=2 delims==" %%i in ('type %CHECK_TEXT_INDICES_LOG%') do set OLD_TEXT_INDICES_DIR=%%i
set TMP_DIR=%OLD_TEXT_INDICES_DIR:"=%
rem debug: echo TMP_DIR=%TMP_DIR%
set TMP_DIR=%TMP_DIR:/=\%
rem debug: echo TMP_DIR=%TMP_DIR%
if "%TMP_DIR%" == "." (
	rem get current directory
	for /f "delims=" %%i in ('cd') do set OLD_TEXT_INDICES_DIR="%%i"
) else (
	if "%TMP_DIR:~1,2%" == ":\" (
		rem Old text indices location is absolute, just store it
		set OLD_TEXT_INDICES_DIR="%TMP_DIR:/=\%"
	) else (
		rem Old text indices location is relative, store it as absolute
		cd /d %OLD_APPLICATION_HOME%\..
		for /f "delims=" %%i in ('cd') do set OLD_TEXT_INDICES_DIR="%%i\%TMP_DIR%"
	)
)
rem debug: echo OLD_TEXT_INDICES_DIR=%OLD_TEXT_INDICES_DIR%
if NOT EXIST %OLD_TEXT_INDICES_DIR% (
	rem debug: echo The old directory is empty
	set /A RETURN_VALUE = 3
	goto :LBLEND
)

REM New TSP
rem =======

rem Check property in the TSP file
set /A N1=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "com.ibm.team.fulltext.indexLocation" %NEW_APP_TSP_FILE%') do set /A N1=%%k
if %N1% EQU 0 (
	rem None was found => return
	call %MSG_FILE_PATH% COPY_INDICES_FAILED %OLD_TEXT_INDICES_DIR% not-defined
	set /A RETURN_VALUE = 2
	goto :LBLEND
)

rem Check at least one line with property is not commented
set /A N2=0
for /F "tokens=1,2* delims=:" %%i in ('%FIND_CMD% /C "#com.ibm.team.fulltext.indexLocation" %NEW_APP_TSP_FILE%') do set /A N2=%%k
if %N2% GEQ %N1% (
	rem All lines with property are commented => return
	call %MSG_FILE_PATH% COPY_INDICES_FAILED %OLD_TEXT_INDICES_DIR% not-defined
	set /A RETURN_VALUE = 2
	goto :LBLEND
)

rem Get the text indices path
%FIND_CMD% "com.ibm.team.fulltext.indexLocation" %NEW_APP_TSP_FILE% | %FIND_CMD% /V "#com.ibm.team.fulltext.indexLocation" > %CHECK_TEXT_INDICES_LOG%
for /F "tokens=2 delims==" %%i in ('type %CHECK_TEXT_INDICES_LOG%') do set NEW_TEXT_INDICES_DIR=%%i
set TMP_DIR=%NEW_TEXT_INDICES_DIR:"=%
set NEW_TEXT_INDICES_DIR="%TMP_DIR:/=\%"
rem debug
rem echo TMP_DIR=%TMP_DIR%
set TMP_DIR=%TMP_DIR:/=\%
rem debug: echo TMP_DIR=%TMP_DIR%
if "%TMP_DIR%" == "." (
	rem get current directory
	for /f "delims=" %%i in ('cd') do set NEW_TEXT_INDICES_DIR="%%i"
) else (
	if "%TMP_DIR:~1,2%" == ":\" (
		rem New text indices location is absolute, just store it
		set NEW_TEXT_INDICES_DIR="%TMP_DIR:/=\%"
	) else (
		rem New text indices location is relative, store it as absolute
		cd /d %NEW_APPLICATION_HOME%\..
		for /f "delims=" %%i in ('cd') do set NEW_TEXT_INDICES_DIR="%%i\%TMP_DIR%"
	)
)
rem debug: echo NEW_TEXT_INDICES_DIR=%NEW_TEXT_INDICES_DIR%

rem Copy the old indices directory to the new indices directory if the two directories are different
if %OLD_TEXT_INDICES_DIR% == %NEW_TEXT_INDICES_DIR% (
	rem debug: 	echo The directories match, not copying indices
	set /A RETURN_VALUE = 0
	goto :LBLEND
)
rem debug: echo The directories do not match, copying indices
xcopy /s /c /i /q /k /o /y %OLD_TEXT_INDICES_DIR% %NEW_TEXT_INDICES_DIR% > nul
set RETURN_VALUE=%ERRORLEVEL%
rem debug: echo RETURN_VALUE=%RETURN_VALUE%

:LBLEND
endlocal & exit /b %RETURN_VALUE%
