@echo off
rem *******************************************************************************
rem  Licensed Materials - Property of IBM
rem  (c) Copyright IBM Corporation 2006, 2011. All Rights Reserved.
rem  
rem  Note to U.S. Government Users Restricted Rights:  
rem  Use, duplication or disclosure restricted by GSA ADP Schedule 
rem  Contract with IBM Corp. 
rem  *******************************************************************************


REM #############################################################
REM #
REM # Define the environment variables corresponding to the
REM # qm_upgrade.bat script parameters and their default values
REM #
REM #===========================================================
REM #
REM # This file is read at the beginning of the qm_upgrade.bat
REM # script execution. It sets one environment variable per
REM # valid parameter with a predefined default value.
REM #
REM # Users may want to modify the default value in order to
REM # launch the qm_upgrade.bat script with their own values
REM # without having to enter the parameter and its
REM # corresponding value manually at the command line.
REM #
REM # WARNING:
REM # Not all variables are required to be set for every
REM # application.  Read each comment carefully before modifying
REM # the value.
REM #
REM #############################################################

rem Parameter: -oldApplicationHome
rem Usage: -oldApplicationHome <dir path>
rem Description:
rem 	Full path to the application home directory in 2.x or 3.0.1 installation.
rem Default:
rem 	<none>
rem Constraints:
rem  - this is a mandatory parameter
rem  - <dir path> must be an existing directory ended by 'server\conf'
rem    e.g. D:\Jazz\IBM\RQM_2.x\jazz\server\conf
rem
set OLD_APPLICATION_HOME=

rem Parameter: -applicationContextRoot
rem Usage: -applicationContextRoot <root>
rem Description:
rem 	Application context root of the 2.x or 3.0.1 server.
rem Default:
rem 	jazz (2.x), qm (3.0.1)
rem Constraints:
rem  - <root> must be a valid directory single name (i.e. no leading slash)
rem
set APPLICATION_CONTEXT_ROOT=

rem Parameter: -updateTomcatFiles
rem Usage: -updateTomcatFiles <yes | no>
rem Description:
rem 	Whether to update the tomcat configuration files.
rem Default:
rem 	yes
rem Constraints:
rem  - The only valid values are 'yes' and 'no'
rem
set UPDATE_TOMCAT_FILES=yes

rem Parameter: -oldTomcatHome
rem Usage: -oldTomcatHome <dir path>
rem Description:
rem 	Full path to the Tomcat root directory in the 2.x or 3.0.1 installation.
rem Default:
rem 	<none>
rem Constraints:
rem  - Must be an existing directory
rem
set OLD_TOMCAT_HOME=

rem Parameter: -newApplicationHome
rem Usage: -newApplicationHome <dir path>
rem Description:
rem 	Path to the Application home directory in the 3.0.1.2 installation.
rem Default:
rem 	conf
rem Constraints:
rem  - Only accepted for RTC, QM and RM upgrade
rem  - When accepted, this is a mandatory parameter
rem  - <dir path> must be an existing directory ended by 'server\conf'
rem    e.g. D:\Jazz\IBM\RQM_3.0\JazzTeamServer\server\conf
rem
set NEW_APPLICATION_HOME="%START_DIR%\conf"

rem Parameter: -newJTSHome
rem Usage: -newJTSHome <dir path>
rem Description:
rem 	Full path to the JTS home directory in the 3.0.1.2 installation.
rem Default:
rem 	The new application home directory
rem Constraints:
rem  - <dir path> must be an existing directory ended by 'server\conf'
rem    e.g. D:\Jazz\IBM\RQM_3.0\JazzTeamServer\server\conf
rem
set NEW_JTS_HOME=

rem Parameter: -jtsContextRoot
rem Usage: -jtsContextRoot <root>
rem Description:
rem 	Context root of the 3.0.1.2 JTS server.
rem Default:
rem 	jts
rem Constraints:
rem  - <root> must be a valid directory single name (i.e. no leading slash)
rem
set JTS_CONTEXT_ROOT=jts

rem Parameter: -newApplicationTomcatHome
rem Usage: -newApplicationTomcatHome <dir path>
rem Description:
rem 	Path to the Application Tomcat root directory in the 3.0.1.2 install.
rem Default:
rem 	<none>
rem
set NEW_TOMCAT_HOME=

rem Parameter: -newJTSTomcatHome
rem Usage: -newJTSTomcatHome <dir path>
rem Description:
rem 	Path to the JTS Tomcat root directory in the 3.0.1.2 install.
rem Default:
rem 	<none>
rem
set NEW_JTS_TOMCAT_HOME=

rem Parameter: -noPrompt
rem Usage: -noPrompt
rem Description:
rem 	Do not prompt before creating or modifying the tables
rem Default:
rem 	<none>
rem Constraints:
rem  - The only valid valued are empty or 'noPrompt'
rem
rem set NO_PROMPT=noPrompt
set NO_PROMPT=

rem Parameter: -noVerify
rem Usage: -noVerify
rem Description:
rem 	Do not perform teamserver.properties files verification.
rem Default:
rem 	<none>
rem Constraints:
rem  - The only valid values are empty or 'noVerify'
rem
rem set NO_VERIFY=noVerify
set NO_VERIFY=

rem Parameter: -overwrite
rem Usage: -overwrite
rem Description:
rem 	Whether to overwrite any existing file.
rem Default:
rem 	no
rem Constraints:
rem  - The only valid values are empty or 'overwrite=yes'
rem
rem set OVERWRITE=overwrite=yes
set OVERWRITE=

rem Parameter: -importFromFile
rem Usage: -importFromFile <file path>
rem Description:
rem 	Import data from 2.x or 3.0.1 exported tar file.
rem Default:
rem 	<none>
rem Constraints:
rem  - The path must point to an existing and valid file
rem
set IMPORT_FROM_FILE=

rem Parameter: -noStepPrompt
rem Usage: -noStepPrompt
rem Description:
rem 	Do not prompt before executing a step.
rem Default:
rem 	false
rem Constraints:
rem  - The only valid values are 'true' or 'false'
rem
rem set NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
